# Changelog for vizta

## [unreleased]
## [v1.0.1] 2025-06-26
### Fixed
- Docs and such.

## [v1.0.0] 2025-06-21
### Changed
- Updated for rebranding

### Fixed
- Compatibility with newer versions of Seaborn

## [v0.0.1] 2022-11-08
### Added
- The first release! :tada:
